@@ -1,12 +1,13 @@
 #![cfg(not(target_arch = "wasm32"))]
 use crate::{
     core::{Invocation, InvocationResponse, WasmCloudEntity},
-    JsonValue, Message, RpcError,
+    Message, RpcError,
 };
 #[allow(unused_imports)]
 use log::{debug, error, trace};
 use ring::digest::{Context, Digest, SHA256};
 use serde::{de::DeserializeOwned, Serialize};
+use serde_json::Value as JsonValue;
 use std::{
     convert::{TryFrom, TryInto},
     io::Read,
@@ -41,6 +42,7 @@ pub struct RpcClient {
 #[derive(Clone)]
 pub(crate) enum NatsClientType {
     Sync(nats::Connection),
+    Asynk(nats::asynk::Connection),
     Async(Arc<crate::provider::NatsClient>),
 }
 
@@ -74,6 +76,21 @@ impl RpcClient {
         }
     }
 
+    /// Constructs a new RpcClient for a nats::asynk connection.
+    /// parameters: async nats client, lattice rpc prefix (usually "default"),
+    /// and secret key for signing messages
+    pub fn new_asynk(
+        nats: nats::asynk::Connection,
+        lattice_prefix: &str,
+        key: wascap::prelude::KeyPair,
+    ) -> Self {
+        RpcClient {
+            client: NatsClientType::Asynk(nats),
+            lattice_prefix: lattice_prefix.to_string(),
+            key: Arc::new(key),
+        }
+    }
+
     /// Constructs a new RpcClient using an async nats connection
     /// parameters: synch nats client connection, lattice rpc prefix (usually "default"),
     /// and secret key for signing messages
@@ -90,7 +107,8 @@ impl RpcClient {
     }
 
     // convenience method for returning async client
-    pub(crate) fn get_async(&self) -> Option<&ratsio::NatsClient> {
+    // If the client is not the correct type, returns None
+    pub fn get_async(&self) -> Option<&ratsio::NatsClient> {
         use std::borrow::Borrow;
         match self.client.borrow() {
             NatsClientType::Async(nats) => Some(nats),
@@ -98,6 +116,16 @@ impl RpcClient {
         }
     }
 
+    // convenience method for returning nats::asynk Connection
+    // If the client is not the correct type, returns None
+    pub fn get_asynk(&self) -> Option<&nats::asynk::Connection> {
+        use std::borrow::Borrow;
+        match self.client.borrow() {
+            NatsClientType::Asynk(nc) => Some(nc),
+            _ => None,
+        }
+    }
+
     /// Send an rpc message using json-encoded data
     pub async fn send_json<Target, Arg, Resp>(
         &self,
@@ -197,6 +225,13 @@ impl RpcClient {
                     .map_err(|e| RpcError::Nats(e.to_string()))?;
                 message.data
             }
+            NatsClientType::Asynk(ref connection) => {
+                let message = connection
+                    .request(subject, data)
+                    .await
+                    .map_err(|e| RpcError::Nats(e.to_string()))?;
+                message.data
+            }
         };
         Ok(bytes)
     }
@@ -213,6 +248,10 @@ impl RpcClient {
             NatsClientType::Sync(connection) => connection
                 .publish(subject, data)
                 .map_err(|e| RpcError::Nats(e.to_string()))?,
+            NatsClientType::Asynk(connection) => connection
+                .publish(subject, data)
+                .await
+                .map_err(|e| RpcError::Nats(e.to_string()))?,
         }
         Ok(())
     }
@@ -319,7 +358,7 @@ impl RpcClientSync {
 }
 
 /// A Json message (method, args)
-struct JsonMessage<'m>(&'m str, crate::JsonValue);
+struct JsonMessage<'m>(&'m str, JsonValue);
 
 impl<'m> TryFrom<JsonMessage<'m>> for Message<'m> {
     /// convert json message to rpc message (msgpack)
